@@ -8,7 +8,7 @@ use parent 'Exporter';
 
 use Sub::Quote;
 
-our $VERSION = '0.40'; # VERSION
+our $VERSION = '0.41'; # VERSION
 
 our @EXPORT = qw(
     alt
@@ -208,7 +208,7 @@ Data::Object::Class::Syntax - Class Declaration DSL for Perl 5
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -230,7 +230,7 @@ version 0.40
     has telephone  => rw;
     has occupation => rw;
 
-    # ATTRIBUTE CONSTRAINTS
+    # CONSTRAINTS
 
     req firstname  => Str;
     req lastname   => Str;
@@ -242,7 +242,7 @@ version 0.40
     opt telephone  => StrMatch[qr/^\d{10,30}$/];
     opt occupation => Str;
 
-    # ATTRIBUTE DEFAULTS
+    # DEFAULTS
 
     def occupation => 'Unassigned';
     def city       => 'San Franscisco';
@@ -250,7 +250,7 @@ version 0.40
 
     1;
 
-=head1 DESCRIPTION
+rhead1 DESCRIPTION
 
 Data::Object::Class::Syntax exports a collection of functions that provide a
 DSL (syntactic sugar) for declaring and describing Data::Object::Class classes.
